package com.inspect.system.mapper;

import com.inspect.system.base.domain.SysDictData;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface SysDictDataMapper {
    List<SysDictData> selectDictDataList(SysDictData sysDictData);

    List<SysDictData> selectDictDataByType(String type);

    String selectDictLabel(@Param("dictType") String dictType, @Param("dictValue") String dictValue);

    SysDictData selectDictDataById(Long id);

    int countDictDataByType(String type);

    int deleteDictDataById(Long id);

    int deleteDictDataByIds(Long[] ids);

    int insertDictData(SysDictData dictData);

    int updateDictData(SysDictData dictData);

    int updateDictDataType(@Param("oldDictType") String oldDictType, @Param("newDictType") String newDictType);
}
